ActivityChangeEvent class

Event fired when the detected device activity changes.

Reports the current activity type and confidence level.

Annotations

Constructors

ActivityChangeEvent({required ActivityType activity, required ActivityConfidence confidence})
Creates a new ActivityChangeEvent.
const
ActivityChangeEvent.fromMap(Map<String, Object?> map)
Creates an ActivityChangeEvent from a platform map.
factory

Properties

activity ActivityType
The detected activity type.
final
confidence ActivityConfidence
The confidence level of the detection.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Serializes to a map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override