ActivityType enum

Activity types detected by the motion detection engine.

Inheritance
Available extensions

Values

still → const ActivityType

Device is stationary.

walking → const ActivityType

User is walking.

running → const ActivityType

User is running.

onFoot → const ActivityType

User is on foot (walking or running, not differentiated).

inVehicle → const ActivityType

User is in a vehicle.

onBicycle → const ActivityType

User is on a bicycle.

unknown → const ActivityType

Activity cannot be determined.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ActivityType>
A constant List of the values in this enum, in order of their declaration.