GeofenceEvent class

Event fired when a geofence transition occurs.

Contains the geofence identifier, the transition action (enter/exit/dwell), and the location at the time of the event.

Annotations

Constructors

GeofenceEvent({required String identifier, required GeofenceAction action, required Location location, Map<String, Object?> extras = const <String, Object?>{}})
Creates a new GeofenceEvent.
const
GeofenceEvent.fromMap(Map<String, Object?> map)
Creates a GeofenceEvent from a platform map.
factory

Properties

action GeofenceAction
The transition action.
final
extras Map<String, Object?>
Extra data from the geofence definition.
final
hashCode int
The hash code for this object.
no setteroverride
identifier String
The identifier of the geofence.
final
location Location
The location at the time of the event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Serializes to a map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override