LocationActivity class

Activity recognition data associated with a location.

Annotations

Constructors

LocationActivity({ActivityType type = ActivityType.unknown, ActivityConfidence confidence = ActivityConfidence.low})
Creates a new LocationActivity.
const
LocationActivity.fromMap(Map<String, Object?> map)
Creates a LocationActivity from a platform map.
factory
LocationActivity.fromTl(TlActivity tl)
Creates a LocationActivity from a Pigeon TlActivity.
factory

Properties

confidence ActivityConfidence
The confidence level of the detection.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ActivityType
The detected activity type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Serializes to a map.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override