LocationAuthorizationRequest enum

The location authorization level to request from the user.

On iOS this maps directly to the CLLocationManager authorization level:

  • always requests "Always" authorization (background tracking).
  • whenInUse requests "When In Use" authorization only.

On Android this is used to decide whether to request ACCESS_BACKGROUND_LOCATION in addition to ACCESS_FINE_LOCATION.

Inheritance
Available extensions

Values

always → const LocationAuthorizationRequest

Request "Always" (background) location authorization.

This is the default and is required for background tracking.

whenInUse → const LocationAuthorizationRequest

Request "When In Use" location authorization only.

Background tracking will not work with this setting on iOS.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocationAuthorizationRequest>
A constant List of the values in this enum, in order of their declaration.