trackingAccuracyThreshold property
Reject locations with accuracy worse than this value (meters).
Implementation
final int trackingAccuracyThreshold;
Reject locations with accuracy worse than this value (meters).
final int trackingAccuracyThreshold;