LogEntry class

Represents a background log entry stored in the local SQLite database.

Constructors

LogEntry({required int id, required String level, required String message, required String timestamp})
Creates a LogEntry.
const
LogEntry.fromTl(TlLogEntry tl)
Converts from Pigeon TlLogEntry.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
The primary key.
final
level String
Log level string (e.g. DEBUG, INFO).
final
message String
Log message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
ISO8601 timestamp string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited