locations property
The location maps about to be synced.
Each map contains the same keys as Location.toMap(). The builder can reshape, filter, or enrich these as needed.
Implementation
final List<Map<String, Object?>> locations;
The location maps about to be synced.
Each map contains the same keys as Location.toMap(). The builder can reshape, filter, or enrich these as needed.
final List<Map<String, Object?>> locations;