TripCarbonSummary class

Per-trip carbon summary emitted when a trip ends.

Constructors

TripCarbonSummary({required double totalCarbonGrams, required double totalDistanceMeters, required Map<String, double> carbonByMode, required Map<String, double> distanceByMode, required String dominantMode})
const

Properties

carbonByMode Map<String, double>
CO₂ grams broken down by transport mode.
final
distanceByMode Map<String, double>
Distance in meters broken down by transport mode.
final
dominantMode String
The transport mode that covered the most distance.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCarbonGrams double
Total CO₂ emitted during the trip (grams).
final
totalDistanceMeters double
Total distance travelled (meters).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited