DeviceInfo class
Information about the device.
- Annotations
Constructors
- DeviceInfo({required String model, required String manufacturer, required String version, required String platform, String framework = 'Flutter'})
-
Creates a new DeviceInfo.
const
-
DeviceInfo.fromMap(Map<
String, Object?> map) -
Creates DeviceInfo from a platform map.
factory
Properties
- framework → String
-
Framework identifier. Always
'Flutter'.final - hashCode → int
-
The hash code for this object.
no setteroverride
- manufacturer → String
-
Device manufacturer (e.g.
'Google','Apple').final - model → String
-
Device model name (e.g.
'Pixel 8','iPhone 15,4').final - platform → String
-
Platform identifier (
'android'or'ios').final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
OS version string (e.g.
'14','17.4').final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Serializes to a map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override