HeadlessEvent class
Event dispatched to the headless (background isolate) callback.
The name identifies the event type (e.g. 'location', 'geofence',
'heartbeat'), and event contains the event payload as a map.
- Annotations
Constructors
-
HeadlessEvent({required String name, required Map<
String, Object?> event}) -
Creates a new HeadlessEvent.
const
-
HeadlessEvent.fromMap(Map<
String, Object?> map) -
Creates a HeadlessEvent from a platform map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Serializes to a map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override