HeartbeatEvent class
Event fired on each heartbeat interval.
Contains the latest known location (which may be stale if the device is stationary and not actively receiving GPS fixes).
- Annotations
Constructors
- HeartbeatEvent({required Location location})
-
Creates a new HeartbeatEvent.
const
-
HeartbeatEvent.fromMap(Map<
String, Object?> map) -
Creates a HeartbeatEvent from a platform map.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Serializes to a map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited