LocationFilter class

GPS filtering and smoothing options.

Annotations

Constructors

LocationFilter({int trackingAccuracyThreshold = 100, int maxImpliedSpeed = 80, int odometerAccuracyThreshold = 50, LocationFilterPolicy policy = LocationFilterPolicy.adjust, bool rejectMockLocations = false, int mockDetectionLevel = 1, bool useKalmanFilter = false})
Creates a new LocationFilter with optional overrides.
const
LocationFilter.fromMap(Map<String, Object?> map)
Creates a LocationFilter from a map.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
maxImpliedSpeed int
Reject locations that imply a speed greater than this value (m/s).
final
mockDetectionLevel int
Sensitivity level for custom mock detection.
final
odometerAccuracyThreshold int
Only count locations with accuracy better than this value toward odometer.
final
policy LocationFilterPolicy
How to handle rejected locations.
final
rejectMockLocations bool
Reject locations flagged as mock by the OS.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingAccuracyThreshold int
Reject locations with accuracy worse than this value (meters).
final
useKalmanFilter bool
Whether the Kalman filter is currently enabled for GPS smoothing.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Serializes to a map.
toString() String
A string representation of this object.
inherited
toTlConfig() → TlLocationFilter
Converts to Pigeon TlLocationFilter.

Operators

operator ==(Object other) bool
The equality operator.
override